@@ -1,41 +1,29 @@
-/************************************************************************************
- * Copyright (C) 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>                *
- *                                                                                  *
- * This program is free software; you can redistribute it and/or                    *
- * modify it under the terms of the GNU General Public License                      *
- * as published by the Free Software Foundation; either version 2                   *
- * of the License, or (at your option) any later version.                           *
- *                                                                                  *
- * This program is distributed in the hope that it will be useful,                  *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
- * GNU General Public License for more details.                                     *
- *                                                                                  *
- * You should have received a copy of the GNU General Public License                *
- * along with this program; if not, write to the Free Software                      *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
- ************************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-#include <qtest.h>
-#include <QJsonObject>
 #include <QJsonArray>
-#include <QStandardPaths>
-#include <QSignalSpy>
+#include <QJsonObject>
 #include <QLoggingCategory>
+#include <QSignalSpy>
+#include <QStandardPaths>
+#include <qtest.h>
 
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KSharedConfig>
 
 #include "alternativesmodeltest.h"
-#include <purpose/job.h>
 #include <purpose/alternativesmodel.h>
 #include <purpose/configuration.h>
+#include <purpose/job.h>
 
 QTEST_GUILESS_MAIN(AlternativesModelTest)
 
-static int saveAsRow(Purpose::AlternativesModel* model)
+static int saveAsRow(Purpose::AlternativesModel *model)
 {
-    for(int i=0, c=model->rowCount(); i<c; ++i) {
+    for (int i = 0, c = model->rowCount(); i < c; ++i) {
         QString pluginId = model->index(i).data(Purpose::AlternativesModel::PluginIdRole).toString();
         if (pluginId == QLatin1String("saveasplugin")) {
             return i;
@@ -48,14 +36,13 @@ static int saveAsRow(Purpose::AlternativesModel* model)
 
 void AlternativesModelTest::initTestCase()
 {
-    // To avoid a runtime dependency on klauncher
-    qputenv("KDE_FORK_SLAVES", "yes");
+    // To let ctest exit, we shouldn't start kio_http_cache_cleaner
+    qputenv("KIO_DISABLE_CACHE_CLEANER", "yes");
 
     if (qEnvironmentVariableIsSet("QT_LOGGING_RULES")) { // as is the case in CI
         // CopyJob debug output is too noisy because of the huge data URL we're using in bigBufferTest.
-        qputenv("QT_LOGGING_RULES", qgetenv("QT_LOGGING_RULES") + QByteArrayLiteral(";kf5.kio.core.copyjob.debug=false"));
+        qputenv("QT_LOGGING_RULES", QByteArray(qgetenv("QT_LOGGING_RULES") + QByteArrayLiteral(";kf.kio.core.copyjob.debug=false")));
     }
-
 }
 
 void AlternativesModelTest::runJobTest()
@@ -64,32 +51,23 @@ void AlternativesModelTest::runJobTest()
 
     const QString tempfile = m_tempDir.path() + QStringLiteral("/purposetest");
     QFile::remove(tempfile);
-    QJsonObject input = QJsonObject {
-        {QStringLiteral("urls"), QJsonArray {QStringLiteral("http://kde.org")} },
-        {QStringLiteral("mimeType"), QStringLiteral("dummy/thing") }
-    };
+    QJsonObject input =
+        QJsonObject{{QStringLiteral("urls"), QJsonArray{QStringLiteral("http://kde.org")}}, {QStringLiteral("mimeType"), QStringLiteral("dummy/thing")}};
     model.setInputData(input);
 
     model.setPluginType(QStringLiteral("Export"));
     model.setDisabledPlugins({});
 
-    Purpose::Configuration* conf = model.configureJob(saveAsRow(&model));
+    Purpose::Configuration *conf = model.configureJob(saveAsRow(&model));
     QVERIFY(!conf->isReady());
     QVERIFY(!conf->createJob());
-    input.insert(QStringLiteral("destinationPath"), QUrl::fromLocalFile(tempfile).url()),
-    conf->setData(input);
+    input.insert(QStringLiteral("destinationPath"), QUrl::fromLocalFile(tempfile).url()), conf->setData(input);
     QVERIFY(conf->isReady());
-    Purpose::Job* job = conf->createJob();
+    Purpose::Job *job = conf->createJob();
     QVERIFY(job);
-    QSignalSpy s(job, &KJob::finished);
     QSignalSpy sOutput(job, &Purpose::Job::outputChanged);
-    job->start();
-    QVERIFY(s.count() || s.wait());
-    if (job->error()) {
-        qWarning() << "error!" << job->error() << job->errorString() << job->errorText();
-    }
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
     QCOMPARE(sOutput.count(), 1);
-    QCOMPARE(job->error(), 0);
     QVERIFY(QFile::remove(tempfile));
 }
 
@@ -97,34 +75,26 @@ void AlternativesModelTest::bigBufferTest()
 {
     Purpose::AlternativesModel model;
 
-    const QByteArray payload(1920*1080*4, 'x');
+    const QByteArray payload(1920 * 1080 * 4, 'x');
     const QString uri = QStringLiteral("data:text/plain;base64,") + QString::fromLatin1(payload.toBase64());
 
     const QString tempfile = m_tempDir.path() + QStringLiteral("/purposetest");
     QFile::remove(tempfile);
-    const QJsonObject input = {
-        {QStringLiteral("urls"), QJsonArray {uri} },
-        {QStringLiteral("mimeType"), QStringLiteral("dummy/thing") },
-        {QStringLiteral("destinationPath"), QUrl::fromLocalFile(tempfile).url()}
-    };
+    const QJsonObject input = {{QStringLiteral("urls"), QJsonArray{uri}},
+                               {QStringLiteral("mimeType"), QStringLiteral("dummy/thing")},
+                               {QStringLiteral("destinationPath"), QUrl::fromLocalFile(tempfile).url()}};
     model.setInputData(input);
     model.setPluginType(QStringLiteral("Export"));
     model.setDisabledPlugins({});
 
-    Purpose::Configuration* conf = model.configureJob(saveAsRow(&model));
+    Purpose::Configuration *conf = model.configureJob(saveAsRow(&model));
     QVERIFY(conf->isReady());
     conf->setUseSeparateProcess(false);
-    Purpose::Job* job = conf->createJob();
+    Purpose::Job *job = conf->createJob();
     QVERIFY(job);
-    QSignalSpy s(job, &KJob::finished);
     QSignalSpy sOutput(job, &Purpose::Job::outputChanged);
-    job->start();
-    QVERIFY(s.count() || s.wait());
-    if (job->error()) {
-        qWarning() << "error!" << job->error() << job->errorString() << job->errorText();
-    }
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
     QCOMPARE(sOutput.count(), 1);
-    QCOMPARE(job->error(), 0);
 
     QFileInfo fi(tempfile);
     QCOMPARE(fi.size(), payload.size());
@@ -136,10 +106,8 @@ void AlternativesModelTest::disablePluginTest()
     const auto listPlugins = [] {
         QStringList plugins;
         Purpose::AlternativesModel model;
-        QJsonObject input = QJsonObject {
-            {QStringLiteral("urls"), QJsonArray {QStringLiteral("http://kde.org")} },
-            {QStringLiteral("mimeType"), QStringLiteral("dummy/thing") }
-        };
+        QJsonObject input =
+            QJsonObject{{QStringLiteral("urls"), QJsonArray{QStringLiteral("http://kde.org")}}, {QStringLiteral("mimeType"), QStringLiteral("dummy/thing")}};
         model.setInputData(input);
         model.setPluginType(QStringLiteral("Export"));
         model.setDisabledPlugins({});
@@ -157,7 +125,7 @@ void AlternativesModelTest::disablePluginTest()
     QStandardPaths::setTestModeEnabled(true);
     auto config = KSharedConfig::openConfig(QStringLiteral("purposerc"));
     auto group = config->group("plugins");
-    group.writeEntry("disabled", QStringList{ QStringLiteral("saveasplugin"), QStringLiteral("emailplugin") });
+    group.writeEntry("disabled", QStringList{QStringLiteral("saveasplugin"), QStringLiteral("emailplugin")});
 
     plugins = listPlugins();
     QVERIFY(!plugins.contains(QStringLiteral("saveasplugin")));
@@ -172,10 +140,8 @@ void AlternativesModelTest::blacklistTest()
     const auto listPlugins = [](const QStringList &blacklist) {
         QStringList plugins;
         Purpose::AlternativesModel model;
-        QJsonObject input = QJsonObject {
-            {QStringLiteral("urls"), QJsonArray {QStringLiteral("http://kde.org")} },
-            {QStringLiteral("mimeType"), QStringLiteral("dummy/thing") }
-        };
+        QJsonObject input =
+            QJsonObject{{QStringLiteral("urls"), QJsonArray{QStringLiteral("http://kde.org")}}, {QStringLiteral("mimeType"), QStringLiteral("dummy/thing")}};
         model.setInputData(input);
         model.setPluginType(QStringLiteral("Export"));
         if (!blacklist.isEmpty()) {
@@ -201,8 +167,10 @@ void AlternativesModelTest::blacklistTest()
     QStandardPaths::setTestModeEnabled(true);
     auto config = KSharedConfig::openConfig(QStringLiteral("purposerc"));
     auto group = config->group("plugins");
-    group.writeEntry("disabled", QStringList{ QStringLiteral("emailplugin") });
+    group.writeEntry("disabled", QStringList{QStringLiteral("emailplugin")});
 
     plugins = listPlugins({QStringLiteral("saveasplugin")});
     QVERIFY(!plugins.contains(QStringLiteral("emailplugin")));
 }
+
+#include "moc_alternativesmodeltest.cpp"
