@@ -12,7 +12,7 @@
 
 #include "menutest.h"
 #include <purpose/alternativesmodel.h>
-#include <purposewidgets/menu.h>
+#include <purpose/menu.h>
 
 QTEST_MAIN(MenuTest)
 
@@ -31,9 +31,6 @@ static QAction *saveAsAction(Purpose::Menu *menu)
 
 void MenuTest::initTestCase()
 {
-    // To avoid a runtime dependency on klauncher
-    qputenv("KDE_FORK_SLAVES", "yes");
-
     // To let ctest exit, we shouldn't start kio_http_cache_cleaner
     qputenv("KIO_DISABLE_CACHE_CLEANER", "yes");
 }
@@ -73,3 +70,5 @@ void MenuTest::runJobTest()
 
     delete menu;
 }
+
+#include "moc_menutest.cpp"
