@@ -10,6 +10,8 @@
 #include <KIO/CopyJob>
 #include <QDebug>
 
+using namespace KAccounts;
+
 QList<QUrl> arrayToList(const QJsonArray &array)
 {
     QList<QUrl> ret;
@@ -73,3 +75,5 @@ void NextcloudJob::gotCredentials(KJob *job)
 
     copyJob->start();
 }
+
+#include "moc_nextcloudjob.cpp"
